HirModule

Struct HirModule 

pub struct HirModule {
    pub functions: Vec<HirFunction>,
    pub imports: Vec<Import>,
    pub type_aliases: Vec<TypeAlias>,
    pub protocols: Vec<Protocol>,
    pub classes: Vec<HirClass>,
    pub constants: Vec<HirConstant>,
    pub top_level_stmts: Vec<HirStmt>,
}
High-level Intermediate Representation of a Python module

HirModule represents a complete Python module after semantic analysis and type inference. It contains all the declarations (functions, classes, imports, etc.) in a form that’s optimized for transpilation to Rust.

Examples

Creating a HIR module manually:

use depyler_core::hir::{HirModule, HirFunction, HirParam, Type, FunctionProperties};
use depyler_annotations::TranspilationAnnotations;
use smallvec::smallvec;

let function = HirFunction {
    name: "example".to_string(),
    params: smallvec![HirParam::new("x".to_string(), Type::Int)],
    ret_type: Type::Int,
    body: vec![],
    properties: FunctionProperties::default(),
    annotations: TranspilationAnnotations::default(),
    docstring: Some("Example function".to_string()),
};

let module = HirModule {
    functions: vec![function],
    imports: vec![],
    type_aliases: vec![],
    protocols: vec![],
    classes: vec![],
    constants: vec![],
};

assert_eq!(module.functions.len(), 1);
assert_eq!(module.functions[0].name, "example");

Fields

functions: Vec<HirFunction>imports: Vec<Import>type_aliases: Vec<TypeAlias>protocols: Vec<Protocol>classes: Vec<HirClass>constants: Vec<HirConstant>top_level_stmts: Vec<HirStmt>

DEPYLER-1216: Top-level statements for script-style Python files. These are non-declarative statements (expressions, loops, etc.) that appear at module scope and should be wrapped into a synthetic main().